@@ -500,7 +500,6 @@ class Field(Nameable):
         obtaining the value from the field-data service. Thus if a cached value
         exists, that is the value that will be returned.
         """
-        # pylint: disable=protected-access
         if xblock is None:
             return self
 
@@ -553,7 +552,6 @@ class Field(Nameable):
         Deletes `xblock` from the underlying data store.
         Deletes are not cached; they are performed immediately.
         """
-        # pylint: disable=protected-access
 
         # Try to perform the deletion on the field_data, and accept
         # that it's okay if the key is not present.  (It may never
@@ -652,7 +650,7 @@ class Field(Nameable):
         """
         Retrieve the value for this field from the specified xblock
         """
-        return self.__get__(xblock, xblock.__class__)
+        return self.__get__(xblock, xblock.__class__)  # pylint: disable=unnecessary-dunder-call
 
     def read_json(self, xblock):
         """
@@ -665,13 +663,13 @@ class Field(Nameable):
         """
         Set the value for this field to value on the supplied xblock
         """
-        self.__set__(xblock, value)
+        self.__set__(xblock, value)  # pylint: disable=unnecessary-dunder-call
 
     def delete_from(self, xblock):
         """
         Delete the value for this field from the supplied xblock
         """
-        self.__delete__(xblock)
+        self.__delete__(xblock)   # pylint: disable=unnecessary-dunder-call
 
     def is_set_on(self, xblock):
         """
@@ -976,10 +974,10 @@ class DateTime(JSONField):
             )
 
         if isinstance(value, datetime.datetime):
-            if value.tzinfo is not None:  # pylint: disable=maybe-no-member
-                return value.astimezone(pytz.utc)  # pylint: disable=maybe-no-member
+            if value.tzinfo is not None:
+                return value.astimezone(pytz.utc)
             else:
-                return value.replace(tzinfo=pytz.utc)  # pylint: disable=maybe-no-member
+                return value.replace(tzinfo=pytz.utc)
         else:
             return value
 
@@ -996,7 +994,7 @@ class DateTime(JSONField):
         if value is None:
             return None
 
-        raise TypeError("Value stored must be a datetime or timedelta object, not {}".format(type(value)))
+        raise TypeError(f"Value stored must be a datetime or timedelta object, not {type(value)}")
 
     def to_string(self, value):
         """DateTime fields get serialized without quote marks."""
@@ -1087,7 +1085,7 @@ def scope_key(instance, xblock):
     """
     scope_key_dict = {}
     scope_key_dict['name'] = instance.name
-    if instance.scope.user == UserScope.NONE or instance.scope.user == UserScope.ALL:
+    if instance.scope.user in [UserScope.NONE, UserScope.ALL]:
         pass
     elif instance.scope.user == UserScope.ONE:
         scope_key_dict['user'] = str(xblock.scope_ids.user_id)
@@ -1123,7 +1121,7 @@ def scope_key(instance, xblock):
         elif char in substitution_list:
             return substitution_list[char]
         else:
-            return "_{}_".format(ord(char))
+            return f"_{ord(char)}_"
 
     for item in ['block', 'name', 'user']:
         if item in scope_key_dict:
