@@ -24,7 +24,7 @@ class AmbiguousPluginError(Exception):
     def __init__(self, all_entry_points):
         classes = (entpt.load() for entpt in all_entry_points)
         desc = ", ".join("{0.__module__}.{0.__name__}".format(cls) for cls in classes)
-        msg = "Ambiguous entry points for {}: {}".format(all_entry_points[0].name, desc)
+        msg = f"Ambiguous entry points for {all_entry_points[0].name}: {desc}"
         super().__init__(msg)
 
 
@@ -68,7 +68,7 @@ class Plugin:
         attribute `plugin_name` on the loaded object
         """
         class_ = entry_point.load()
-        setattr(class_, 'plugin_name', entry_point.name)
+        class_.plugin_name = entry_point.name
         return class_
 
     @classmethod
@@ -167,9 +167,9 @@ class Plugin:
         )
         entry_point.name = identifier
 
-        def _decorator(func):                           # pylint: disable=C0111
+        def _decorator(func):
             @functools.wraps(func)
-            def _inner(*args, **kwargs):                # pylint: disable=C0111
+            def _inner(*args, **kwargs):
                 global PLUGIN_CACHE  # pylint: disable=global-statement
 
                 old = list(cls.extra_entry_points)
