@@ -7,7 +7,7 @@ import warnings
 from unittest.mock import Mock
 from django.test import TestCase
 from django.utils import translation
-from django.utils.translation import gettext_lazy as _  # pylint: disable=import-error
+from django.utils.translation import gettext_lazy as _
 
 from xblock.core import XBlock
 from xblock.fields import FailingEnforceTypeWarning, Scope, String, ScopeIds
