@@ -1,7 +1,7 @@
 """
 Tests for classes extending Field.
 """
-# pylint: disable=abstract-class-instantiated, protected-access
+# pylint: disable=protected-access
 from contextlib import contextmanager
 import datetime as dt
 import itertools
@@ -269,7 +269,6 @@ class XMLStringTest(FieldTest):
         b'<invalid_utf8_bytes char="\xe1"/>',
     )
     def test_bad_xml(self, input_text):
-        # pylint: disable=no-member
         xml_string = self.FIELD_TO_TEST(enforce_type=True)
         self.assertRaises(etree.XMLSyntaxError, xml_string.to_json, input_text)
         unchecked_xml_string = self.FIELD_TO_TEST(enforce_type=False)
@@ -438,7 +437,7 @@ class SetTest(FieldTest):
         self.assertJSONOrSetEquals({'foo', 'bar'}, {'foo', 'bar'})
         self.assertJSONOrSetEquals({'bar', 'foo'}, {'foo', 'bar'})
         self.assertJSONOrSetEquals({1, 3.14}, {1, 3.14})
-        self.assertJSONOrSetEquals({1, 3.14}, {1, 3.14, 1})
+        self.assertJSONOrSetEquals({1, 3.14}, {1, 3.14, 1})  # pylint: disable=duplicate-value
 
     def test_hashable_converts(self):
         self.assertJSONOrSetEquals({1, 3.4}, [1, 3.4])
